'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const syntax_1 = require("@glimmer/syntax");
const process_template_1 = require("../helpers/process-template");
const html_1 = require("../../lib/html");
describe('Helper #appendToAttrContent', function () {
    it('it can append undefined (which does nothing)', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(undefined, attr.value);
                attr.value = html_1.appendToAttrContent(undefined, attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo"></div>`);
    });
    it('it can append null (which does nothing)', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(null, attr.value);
                attr.value = html_1.appendToAttrContent(null, attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo"></div>`);
    });
    it('it can append regular strings', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent('bar', attr.value);
                attr.value = html_1.appendToAttrContent('baz', attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo bar baz"></div>`);
    });
    it('it can append StringLiterals', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.string('bar'), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.string('baz'), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo bar baz"></div>`);
    });
    it('it can append NumberLiterals', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.number(1), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.number(2), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo 1 2"></div>`);
    });
    it('it can append TextNodes to another TextNode', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.text('bar'), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.text('baz'), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo bar baz"></div>`);
    });
    it('it can append PathExpression', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('bar'), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('baz'), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo {{bar}} {{baz}}"></div>`);
    });
    it('it can append MustacheStatement', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('bar')), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('baz')), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('if'), [syntax_1.builders.path('condition'), syntax_1.builders.string('yes'), syntax_1.builders.string('no')]), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo {{bar}} {{baz}} {{if condition "yes" "no"}}"></div>`);
    });
    it('it can append SubExpressions', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.sexpr(syntax_1.builders.path('some-helper'), [syntax_1.builders.string('someArg')]), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.sexpr(syntax_1.builders.path('if'), [syntax_1.builders.path('condition'), syntax_1.builders.string('yes'), syntax_1.builders.string('no')]), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo {{some-helper "someArg"}} {{if condition "yes" "no"}}"></div>`);
    });
    it('it can append ConcatStatements', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                let val = syntax_1.builders.concat([syntax_1.builders.text('prefix'), syntax_1.builders.mustache(syntax_1.builders.path('boundVal')), syntax_1.builders.text('suffix')]);
                attr.value = html_1.appendToAttrContent(val, attr.value);
                let val2 = syntax_1.builders.concat([syntax_1.builders.text('prefix2'), syntax_1.builders.mustache(syntax_1.builders.path('boundVal2'))]);
                attr.value = html_1.appendToAttrContent(val2, attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="foo prefix{{boundVal}}suffix prefix2{{boundVal2}}"></div>`);
    });
    it('it can mix and append a mix of elements', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('one')), syntax_1.builders.text(''));
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('two')), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.text('three'), attr.value);
                attr.value = html_1.appendToAttrContent('four', attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('five'), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('if'), [syntax_1.builders.path('condition'), syntax_1.builders.string('yes'), syntax_1.builders.string('no')]), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('six'), attr.value);
                attr.value = html_1.appendToAttrContent(syntax_1.builders.concat([syntax_1.builders.mustache(syntax_1.builders.path('sev')), syntax_1.builders.text('en')]), attr.value);
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="{{one}} {{two}} three four {{five}} {{if condition "yes" "no"}} {{six}} {{sev}}en"></div>`);
    });
    it('it can mix and append a mix of elements without prepending spaces', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode(attr) {
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('one')), syntax_1.builders.text(''), { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('two')), attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.text('three'), attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent('four', attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('five'), attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.mustache(syntax_1.builders.path('if'), [syntax_1.builders.path('condition'), syntax_1.builders.string('yes'), syntax_1.builders.string('no')]), attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.path('six'), attr.value, { prependSpace: false });
                attr.value = html_1.appendToAttrContent(syntax_1.builders.concat([syntax_1.builders.mustache(syntax_1.builders.path('sev')), syntax_1.builders.text('en')]), attr.value, { prependSpace: false });
                return attr;
            }
        });
        expect(modifiedTemplate).toEqual(`<div class="{{one}}{{two}}threefour{{five}}{{if condition "yes" "no"}}{{six}}{{sev}}en"></div>`);
    });
});
