'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const syntax_1 = require("@glimmer/syntax");
const process_template_1 = require("../helpers/process-template");
const html_1 = require("../../lib/html");
describe('Helper #appendToContent', function () {
    it('it builds attrs given a string', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', 'new content');
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class="new content"></div>`);
    });
    it('it builds attrs given a TextNode', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.text('new content'));
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class="new content"></div>`);
    });
    it('it builds attrs given a StringLiteral', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.string('new content'));
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class="new content"></div>`);
    });
    it('it builds attrs given a BooleanLiteral', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.boolean(true));
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class=""></div>`);
        modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.boolean(false));
            }
        });
        expect(modifiedTemplate).toEqual(`<div></div>`);
    });
    it('it builds attrs given a NumberLiteral', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.number(2));
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class="2"></div>`);
        modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.boolean(false));
            }
        });
        expect(modifiedTemplate).toEqual(`<div></div>`);
    });
    it('it builds attrs given a PathExpression', function () {
        let modifiedTemplate = process_template_1.default(`<div class="foo"></div>`, {
            AttrNode() {
                return html_1.buildAttr('not-class', syntax_1.builders.path('boundValue'));
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class={{boundValue}}></div>`);
    });
    it('it builds attrs given a SubExpression', function () {
        let modifiedTemplate = process_template_1.default(`{{some-helper title=(concat 'a' 'b')}}`, {
            MustacheStatement(node) {
                let title = node.hash.pairs.filter((p) => p.key === 'title')[0];
                if (title !== undefined) {
                    let attrs = [];
                    let attr = html_1.buildAttr('not-class', title.value);
                    if (attr) {
                        attrs.push(attr);
                    }
                    return syntax_1.builders.element('div', attrs);
                }
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class={{concat "a" "b"}}></div>`);
    });
    it('it builds attrs given a ConcatStatement without superfluous quotes', function () {
        let modifiedTemplate = process_template_1.default(`{{some-helper}}`, {
            MustacheStatement(node) {
                if (node.path.original === 'some-helper') {
                    let condition = syntax_1.builders.mustache(syntax_1.builders.path('if'), [syntax_1.builders.path('cond'), syntax_1.builders.string('yes'), syntax_1.builders.string('no')]);
                    let attr = html_1.buildAttr('not-class', syntax_1.builders.concat([condition]));
                    ;
                    return syntax_1.builders.element('div', [attr]);
                }
            }
        });
        expect(modifiedTemplate).toEqual(`<div not-class={{if cond "yes" "no"}}></div>`);
    });
});
