'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const syntax_1 = require("@glimmer/syntax");
const process_template_1 = require("../../helpers/process-template");
const html_1 = require("../../../lib/html");
describe('Helper #buildToAttrContent', function () {
    it('receives an array of mixed types and builds the content for an attribute efficiently', function () {
        let attrContent;
        let modifiedTemplate = process_template_1.default(`{{my-foo}}`, {
            MustacheStatement(node) {
                if (node.path.original === 'my-foo') {
                    attrContent = html_1.buildAttrContent([
                        'rawstring',
                        1,
                        syntax_1.builders.string('StringLiteral'),
                        syntax_1.builders.number('2'),
                        syntax_1.builders.undefined(),
                        syntax_1.builders.null(),
                        syntax_1.builders.path('Path'),
                        syntax_1.builders.text('TextNode'),
                        syntax_1.builders.sexpr(syntax_1.builders.path('concat'), [syntax_1.builders.path('firstName'), syntax_1.builders.path('lastName')]),
                    ]);
                    let attr = html_1.buildAttr('class', attrContent);
                    let attrs = attr ? [attr] : [];
                    return syntax_1.builders.element('div', attrs);
                }
            }
        });
        expect(attrContent).toHaveProperty('type', 'ConcatStatement');
        expect(modifiedTemplate).toEqual(`<div class="rawstring1StringLiteral2{{Path}}TextNode{{concat firstName lastName}}"></div>`);
    });
    it('mixes and joins consecurive string-like arguments', function () {
        let attrContent;
        let modifiedTemplate = process_template_1.default(`{{my-foo}}`, {
            MustacheStatement(node) {
                if (node.path.original === 'my-foo') {
                    attrContent = html_1.buildAttrContent([
                        'rawstring',
                        1,
                        syntax_1.builders.string('StringLiteral'),
                        syntax_1.builders.number('2'),
                        syntax_1.builders.undefined(),
                        syntax_1.builders.text('TextNode'),
                        syntax_1.builders.null(),
                        'LastString'
                    ]);
                    let attr = html_1.buildAttr('class', attrContent);
                    let attrs = attr ? [attr] : [];
                    return syntax_1.builders.element('div', attrs);
                }
            }
        });
        expect(attrContent).toHaveProperty('type', 'TextNode');
        expect(modifiedTemplate).toEqual(`<div class="rawstring1StringLiteral2TextNodeLastString"></div>`);
    });
});
